@@ -74,17 +74,22 @@ def define(db) -> dict:
         'frame': Table('Frame', db.MetaData,
                        Column('Name', Text, nullable=False),
                        Column('Sheet', Text, ForeignKey('Sheet.Name', name='R300'), nullable=False),
-                       PrimaryKeyConstraint('Name', 'Sheet', name='I1'),
+                       Column('Orientation', Enum('landscape', 'portrait', name='enum_SheetOrientation'),
+                              nullable=False),
+                       PrimaryKeyConstraint('Name', 'Sheet', 'Orientation', name='I1'),
                        ),
         'titleblock_placement': Table('Title Block Placement', db.MetaData,
                                       Column('Frame', Text, nullable=False),
                                       Column('Sheet', Text, nullable=False),
+                                      Column('Orientation', Enum('landscape', 'portrait', name='enum_SheetOrientation'),
+                                             nullable=False),
                                       Column('Title block pattern', Text, nullable=False),
                                       Column('Sheet size group', Text, nullable=False),
                                       Column('X', Integer, nullable=False),
                                       Column('Y', Integer, nullable=False),
-                                      PrimaryKeyConstraint('Frame', 'Sheet', name='I1'),
-                                      ForeignKeyConstraint(('Frame', 'Sheet'), ['Frame.Name', 'Frame.Sheet'],
+                                      PrimaryKeyConstraint('Frame', 'Sheet', 'Orientation', name='I1'),
+                                      ForeignKeyConstraint(('Frame', 'Sheet', 'Orientation'),
+                                                           ['Frame.Name', 'Frame.Sheet', 'Frame.Orientation'],
                                                            name='R315_F'),
                                       ForeignKeyConstraint(('Title block pattern', 'Sheet size group'),
                                                            ['Scaled Title Block.Title block pattern',
@@ -93,16 +98,25 @@ def define(db) -> dict:
         'box_placement': Table('Box Placement', db.MetaData,
                                Column('Frame', Text, nullable=False),
                                Column('Sheet', Text, nullable=False),
+                               Column('Orientation', Enum('landscape', 'portrait', name='enum_SheetOrientation'),
+                                      nullable=False),
                                Column('Title block pattern', Text, nullable=False),
                                Column('Box', Integer, nullable=False),
                                Column('X', Integer, nullable=False),
                                Column('Y', Integer, nullable=False),
                                Column('Width', Float, nullable=False),
                                Column('Height', Float, nullable=False),
-                               PrimaryKeyConstraint('Frame', 'Sheet', 'Title block pattern', 'Box', name='I1'),
-                               # Constraint below keeps failing for some reason so it is commented out for now
+                               PrimaryKeyConstraint('Frame', 'Sheet', 'Orientation',
+                                                    'Title block pattern', 'Box', name='I1'),
+                               # TODO: Constraint below keeps failing for some reason so it is commented out for now
+                               # 2nd attempt
+                               # ForeignKeyConstraint(('Frame', 'Sheet', 'Orientation', 'Title block pattern'),
+                               #                      ['Title Block Placement.Frame', 'Title Block Placement.Sheet',
+                               #                       'Title Block Placement.Orientation',
+                               #                       'Title Block Placement.Title block pattern'], name='R318_TBP'),
+                               # 1st attempt
                                # And, yes, I have checked EVERYTHING.  It is a total mystery
-                               # ForeignKeyConstraint(('Frame', 'Sheet', 'Title block pattern',),
+                               # ForeignKeyConstraint(('Frame', 'Sheet', 'Orientation', 'Title block pattern',),
                                #     ['Title Block Placement.Frame', 'Title Block Placement.Sheet'], name='R318_TBP'),
                                ),
         'box_text_line': Table('Box Text Line', db.MetaData,
@@ -120,12 +134,15 @@ def define(db) -> dict:
                             Column('Metadata', Text, ForeignKey('Metadata.Name', name='R305_R307_M'), nullable=False),
                             Column('Frame', Text, nullable=False),
                             Column('Sheet', Text, nullable=False),
+                            Column('Orientation', Enum('landscape', 'portrait', name='enum_SheetOrientation'),
+                                   nullable=False),
                             Column('x position', Integer, nullable=False),
                             Column('y position', Integer, nullable=False),
                             Column('max width', Integer, nullable=False),
                             Column('max height', Integer, nullable=False),
-                            PrimaryKeyConstraint('Metadata', 'Frame', 'Sheet', name='I1'),
-                            ForeignKeyConstraint(('Frame', 'Sheet'), ['Frame.Name', 'Frame.Sheet'],
+                            PrimaryKeyConstraint('Metadata', 'Frame', 'Sheet', 'Orientation', name='I1'),
+                            ForeignKeyConstraint(('Frame', 'Sheet', 'Orientation'),
+                                                 ['Frame.Name', 'Frame.Sheet', 'Frame.Orientation'],
                                                  name='R305_R307_F'),
                             ),
         'diagram_layout_specification': Table('Diagram Layout Specification', db.MetaData,
@@ -195,6 +212,7 @@ def define(db) -> dict:
         'compartment_type': Table('Compartment Type', db.MetaData,
                                   Column('Name', String, nullable=False),
                                   Column('Horizontal alignment', String(10), nullable=False),
+                                  Column('Vertical alignment', String(10), nullable=False),
                                   Column('Pad top', Integer, nullable=False),
                                   Column('Pad bottom', Integer, nullable=False),
                                   Column('Pad left', Integer, nullable=False),
@@ -396,8 +414,13 @@ def define(db) -> dict:
                        Column('Name', String, primary_key=True),
                        Column('R', Integer, nullable=False),
                        Column('G', Integer, nullable=False),
-                       Column('B', Integer, nullable=False)
+                       Column('B', Integer, nullable=False),
+                       Column('Purpose', String, nullable=False),
                        ),
+        'color_usage': Table('Color Usage', db.MetaData,
+                             Column('Name', String, primary_key=True),
+                             Column('Color', String, ForeignKey('Color.Name'), nullable=False),
+                             ),
         'typeface': Table('Typeface', db.MetaData,
                           Column('Alias', String, primary_key=True),
                           Column('Name', String, unique=True),
@@ -442,6 +465,7 @@ def define(db) -> dict:
                                    Column('Presentation', String, nullable=False),
                                    Column('Drawing type', String, nullable=False),
                                    Column('Text style', String, nullable=False),
+                                   Column('Underlay', Boolean, nullable=False),
                                    PrimaryKeyConstraint('Asset', 'Presentation', 'Drawing type', name='I1'),
                                    ForeignKeyConstraint(('Asset', 'Drawing type'),
                                                         ['Asset.Name', 'Asset.Drawing type'],
@@ -463,6 +487,18 @@ def define(db) -> dict:
                                                          ['Presentation.Name', 'Presentation.Drawing type'],
                                                          name='R5_R4_pstyle'),
                                     ),
+        'corner_spec': Table('Corner Spec', db.MetaData,
+                                   Column('Asset', String, nullable=False),
+                                   Column('Presentation', String, nullable=False),
+                                   Column('Drawing type', String, nullable=False),
+                                   Column('Radius', Integer, nullable=False),
+                                   Column('Top', Boolean, nullable=False),
+                                   Column('Bottom', Boolean, nullable=False),
+                                   PrimaryKeyConstraint('Asset', 'Presentation', 'Drawing type', name='I1'),
+                                   ForeignKeyConstraint(('Asset', 'Presentation', 'Drawing type'),
+                                                        ['Shape Presentation.Asset', 'Shape Presentation.Presentation',
+                                                         'Shape Presentation.Drawing type'], name='R18')
+                                   ),
         'closed_shape_fill': Table('Closed Shape Fill', db.MetaData,
                                    Column('Asset', String, nullable=False),
                                    Column('Presentation', String, nullable=False),
