@@ -42,12 +42,12 @@ def nearest_parallel_segment(psegs: Set[tuple], point: Position, ascending: bool
     if ascending:  # Now select the closest axis value to the point
         axis_value = min({s[0][axis_coord] for s in isegs})
     else:
-        axis_value = max({s[0][axis_coord] for s in isegs})
+       axis_value = max({s[0][axis_coord] for s in isegs})
     return axis_value
 
 
 
-def step_edge_distance(num_of_steps, extent, step):
+def step_edge_distance(num_of_steps: int, extent: float, step: int):
     """
     You have a line segment with a given extent (length). In distance coordinates such as points, 0 is at the
     beginning of the segment increasing to the extent at the other end. A number line is defined with step
